summaryrefslogtreecommitdiffhomepage
path: root/dev/kernel/KernelKit/MemoryMgr.h
diff options
context:
space:
mode:
Diffstat (limited to 'dev/kernel/KernelKit/MemoryMgr.h')
-rw-r--r--dev/kernel/KernelKit/MemoryMgr.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/dev/kernel/KernelKit/MemoryMgr.h b/dev/kernel/KernelKit/MemoryMgr.h
index e2b8aa2f..229b6aa6 100644
--- a/dev/kernel/KernelKit/MemoryMgr.h
+++ b/dev/kernel/KernelKit/MemoryMgr.h
@@ -9,13 +9,13 @@
/// @date 30/01/24
/// @file: MemoryMgr.h
/// @brief: heap allocation support.
#include <NewKit/KernelPanic.h>
#include <KernelKit/KPC.h>
#include <hint/CompilerHint.h>
-namespace NeOS
+namespace Kernel
{
/// @brief Declare pointer as free.
/// @param heap_ptr the pointer.
@@ -66,7 +66,7 @@ namespace NeOS
{
if (*cls)
{
- err_global_get() = NeOS::kErrorInvalidData;
+ err_global_get() = Kernel::kErrorInvalidData;
return NO;
}
@@ -82,6 +82,6 @@ namespace NeOS
delete *cls;
*cls = nullptr;
}
-} // namespace NeOS
+} // namespace Kernel
#endif // !INC_KERNEL_HEAP_H
@@ -9,13 +9,13 @@
/// @date 30/01/24
/// @file: MemoryMgr.h
-/// @brief: heap allocation support.
+/// @brief: Memory allocation support for the NeKernel.
#include <NewKit/KernelPanic.h>
#include <KernelKit/KPC.h>